Class: Google::Apis::TexttospeechV1::AudioConfig
- Inherits:
-
Object
- Object
- Google::Apis::TexttospeechV1::AudioConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/texttospeech_v1/classes.rb,
lib/google/apis/texttospeech_v1/representations.rb,
lib/google/apis/texttospeech_v1/representations.rb
Overview
Description of audio data to be synthesized.
Instance Attribute Summary collapse
-
#audio_encoding ⇒ String
Required.
-
#effects_profile_id ⇒ Array<String>
Optional.
-
#pitch ⇒ Float
Optional.
-
#sample_rate_hertz ⇒ Fixnum
Optional.
-
#speaking_rate ⇒ Float
Optional.
-
#volume_gain_db ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AudioConfig
constructor
A new instance of AudioConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AudioConfig
Returns a new instance of AudioConfig.
124 125 126 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_encoding ⇒ String
Required. The format of the audio byte stream.
Corresponds to the JSON property audioEncoding
75 76 77 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 75 def audio_encoding @audio_encoding end |
#effects_profile_id ⇒ Array<String>
Optional. Input only. An identifier which selects 'audio effects' profiles
that are applied on (post synthesized) text to speech. Effects are applied on
top of each other in the order they are given. See audio profiles for current supported
profile ids.
Corresponds to the JSON property effectsProfileId
84 85 86 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 84 def effects_profile_id @effects_profile_id end |
#pitch ⇒ Float
Optional. Input only. Speaking pitch, in the range [-20.0, 20.0]. 20 means
increase 20 semitones from the original pitch. -20 means decrease 20 semitones
from the original pitch.
Corresponds to the JSON property pitch
91 92 93 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 91 def pitch @pitch end |
#sample_rate_hertz ⇒ Fixnum
Optional. The synthesis sample rate (in hertz) for this audio. When this is
specified in SynthesizeSpeechRequest, if this is different from the voice's
natural sample rate, then the synthesizer will honor this request by
converting to the desired sample rate (which might result in worse audio
quality), unless the specified sample rate is not supported for the encoding
chosen, in which case it will fail the request and return google.rpc.Code.
INVALID_ARGUMENT.
Corresponds to the JSON property sampleRateHertz
102 103 104 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 102 def sample_rate_hertz @sample_rate_hertz end |
#speaking_rate ⇒ Float
Optional. Input only. Speaking rate/speed, in the range [0.25, 2.0]. 1.0 is
the normal native speed supported by the specific voice. 2.0 is twice as fast,
and 0.5 is half as fast. If unset(0.0), defaults to the native 1.0 speed. Any
other values < 0.25 or > 2.0 will return an error.
Corresponds to the JSON property speakingRate
110 111 112 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 110 def speaking_rate @speaking_rate end |
#volume_gain_db ⇒ Float
Optional. Input only. Volume gain (in dB) of the normal native volume
supported by the specific voice, in the range [-96.0, 16.0]. If unset, or set
to a value of 0.0 (dB), will play at normal native signal amplitude. A value
of -6.0 (dB) will play at approximately half the amplitude of the normal
native signal amplitude. A value of +6.0 (dB) will play at approximately twice
the amplitude of the normal native signal amplitude. Strongly recommend not to
exceed +10 (dB) as there's usually no effective increase in loudness for any
value greater than that.
Corresponds to the JSON property volumeGainDb
122 123 124 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 122 def volume_gain_db @volume_gain_db end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
129 130 131 132 133 134 135 136 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 129 def update!(**args) @audio_encoding = args[:audio_encoding] if args.key?(:audio_encoding) @effects_profile_id = args[:effects_profile_id] if args.key?(:effects_profile_id) @pitch = args[:pitch] if args.key?(:pitch) @sample_rate_hertz = args[:sample_rate_hertz] if args.key?(:sample_rate_hertz) @speaking_rate = args[:speaking_rate] if args.key?(:speaking_rate) @volume_gain_db = args[:volume_gain_db] if args.key?(:volume_gain_db) end |