Class: Google::Apis::TexttospeechV1::CustomPronunciationParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/texttospeech_v1/classes.rb,
lib/google/apis/texttospeech_v1/representations.rb,
lib/google/apis/texttospeech_v1/representations.rb

Overview

Pronunciation customization for a phrase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomPronunciationParams

Returns a new instance of CustomPronunciationParams.



173
174
175
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#phonetic_encodingString

The phonetic encoding of the phrase. Corresponds to the JSON property phoneticEncoding

Returns:

  • (String)


159
160
161
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 159

def phonetic_encoding
  @phonetic_encoding
end

#phraseString

The phrase to which the customization is applied. The phrase can be multiple words, such as proper nouns, but shouldn't span the length of the sentence. Corresponds to the JSON property phrase

Returns:

  • (String)


165
166
167
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 165

def phrase
  @phrase
end

#pronunciationString

The pronunciation of the phrase. This must be in the phonetic encoding specified above. Corresponds to the JSON property pronunciation

Returns:

  • (String)


171
172
173
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 171

def pronunciation
  @pronunciation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



178
179
180
181
182
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 178

def update!(**args)
  @phonetic_encoding = args[:phonetic_encoding] if args.key?(:phonetic_encoding)
  @phrase = args[:phrase] if args.key?(:phrase)
  @pronunciation = args[:pronunciation] if args.key?(:pronunciation)
end