Class: Google::Apis::TexttospeechV1::AdvancedVoiceOptions
- Inherits:
-
Object
- Object
- Google::Apis::TexttospeechV1::AdvancedVoiceOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/texttospeech_v1/classes.rb,
lib/google/apis/texttospeech_v1/representations.rb,
lib/google/apis/texttospeech_v1/representations.rb
Overview
Used for advanced voice options.
Instance Attribute Summary collapse
-
#enable_textnorm ⇒ Boolean
(also: #enable_textnorm?)
Optional.
-
#low_latency_journey_synthesis ⇒ Boolean
(also: #low_latency_journey_synthesis?)
Only for Journey voices.
-
#relax_safety_filters ⇒ Boolean
(also: #relax_safety_filters?)
Optional.
-
#safety_settings ⇒ Google::Apis::TexttospeechV1::SafetySettings
Safety settings for the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdvancedVoiceOptions
constructor
A new instance of AdvancedVoiceOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdvancedVoiceOptions
Returns a new instance of AdvancedVoiceOptions.
55 56 57 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 55 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_textnorm ⇒ Boolean Also known as: enable_textnorm?
Optional. If true, textnorm will be applied to text input. This feature is
enabled by default. Only applies for Gemini TTS.
Corresponds to the JSON property enableTextnorm
33 34 35 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 33 def enable_textnorm @enable_textnorm end |
#low_latency_journey_synthesis ⇒ Boolean Also known as: low_latency_journey_synthesis?
Only for Journey voices. If false, the synthesis is context aware and has a
higher latency.
Corresponds to the JSON property lowLatencyJourneySynthesis
40 41 42 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 40 def low_latency_journey_synthesis @low_latency_journey_synthesis end |
#relax_safety_filters ⇒ Boolean Also known as: relax_safety_filters?
Optional. Input only. Deprecated, use safety_settings instead. If true,
relaxes safety filters for Gemini TTS.
Corresponds to the JSON property relaxSafetyFilters
47 48 49 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 47 def relax_safety_filters @relax_safety_filters end |
#safety_settings ⇒ Google::Apis::TexttospeechV1::SafetySettings
Safety settings for the request.
Corresponds to the JSON property safetySettings
53 54 55 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 53 def safety_settings @safety_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60 61 62 63 64 65 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 60 def update!(**args) @enable_textnorm = args[:enable_textnorm] if args.key?(:enable_textnorm) @low_latency_journey_synthesis = args[:low_latency_journey_synthesis] if args.key?(:low_latency_journey_synthesis) @relax_safety_filters = args[:relax_safety_filters] if args.key?(:relax_safety_filters) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) end |