Class: Google::Apis::TexttospeechV1::MultiSpeakerVoiceConfig
- Inherits:
-
Object
- Object
- Google::Apis::TexttospeechV1::MultiSpeakerVoiceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/texttospeech_v1/classes.rb,
lib/google/apis/texttospeech_v1/representations.rb,
lib/google/apis/texttospeech_v1/representations.rb
Overview
Configuration for a multi-speaker text-to-speech setup. Enables the use of up to two distinct voices in a single synthesis request.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiSpeakerVoiceConfig
constructor
A new instance of MultiSpeakerVoiceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiSpeakerVoiceConfig
Returns a new instance of MultiSpeakerVoiceConfig.
346 347 348 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#speaker_voice_configs ⇒ Array<Google::Apis::TexttospeechV1::MultispeakerPrebuiltVoice>
Required. A list of configurations for the voices of the speakers. Exactly two
speaker voice configurations must be provided.
Corresponds to the JSON property speakerVoiceConfigs
344 345 346 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 344 def speaker_voice_configs @speaker_voice_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
351 352 353 |
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 351 def update!(**args) @speaker_voice_configs = args[:speaker_voice_configs] if args.key?(:speaker_voice_configs) end |