Class: Google::Apis::TexttospeechV1::VoiceSelectionParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/texttospeech_v1/classes.rb,
lib/google/apis/texttospeech_v1/representations.rb,
lib/google/apis/texttospeech_v1/representations.rb

Overview

Description of which voice to use for a synthesis request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VoiceSelectionParams

Returns a new instance of VoiceSelectionParams.



817
818
819
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_voiceGoogle::Apis::TexttospeechV1::CustomVoiceParams

Description of the custom voice to be synthesized. Corresponds to the JSON property customVoice



768
769
770
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 768

def custom_voice
  @custom_voice
end

#language_codeString

Required. The language (and potentially also the region) of the voice expressed as a BCP-47 language tag, e.g. "en-US". This should not include a script tag (e.g. use "cmn-cn" rather than "cmn-Hant-cn"), because the script will be inferred from the input provided in the SynthesisInput. The TTS service will use this parameter to help choose an appropriate voice. Note that the TTS service may choose a voice with a slightly different language code than the one selected; it may substitute a different region (e.g. using en-US rather than en-CA if there isn' t a Canadian voice available), or even a different language, e.g. using "nb" ( Norwegian Bokmal) instead of "no" (Norwegian)". Corresponds to the JSON property languageCode

Returns:

  • (String)


782
783
784
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 782

def language_code
  @language_code
end

#model_nameString

Optional. The name of the model. If set, the service will choose the model matching the specified configuration. Corresponds to the JSON property modelName

Returns:

  • (String)


788
789
790
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 788

def model_name
  @model_name
end

#multi_speaker_voice_configGoogle::Apis::TexttospeechV1::MultiSpeakerVoiceConfig

Configuration for a multi-speaker text-to-speech setup. Enables the use of up to two distinct voices in a single synthesis request. Corresponds to the JSON property multiSpeakerVoiceConfig



794
795
796
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 794

def multi_speaker_voice_config
  @multi_speaker_voice_config
end

#nameString

The name of the voice. If both the name and the gender are not set, the service will choose a voice based on the other parameters such as language_code. Corresponds to the JSON property name

Returns:

  • (String)


801
802
803
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 801

def name
  @name
end

#ssml_genderString

The preferred gender of the voice. If not set, the service will choose a voice based on the other parameters such as language_code and name. Note that this is only a preference, not requirement; if a voice of the appropriate gender is not available, the synthesizer should substitute a voice with a different gender rather than failing the request. Corresponds to the JSON property ssmlGender

Returns:

  • (String)


810
811
812
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 810

def ssml_gender
  @ssml_gender
end

#voice_cloneGoogle::Apis::TexttospeechV1::VoiceCloneParams

The configuration of Voice Clone feature. Corresponds to the JSON property voiceClone



815
816
817
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 815

def voice_clone
  @voice_clone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



822
823
824
825
826
827
828
829
830
# File 'lib/google/apis/texttospeech_v1/classes.rb', line 822

def update!(**args)
  @custom_voice = args[:custom_voice] if args.key?(:custom_voice)
  @language_code = args[:language_code] if args.key?(:language_code)
  @model_name = args[:model_name] if args.key?(:model_name)
  @multi_speaker_voice_config = args[:multi_speaker_voice_config] if args.key?(:multi_speaker_voice_config)
  @name = args[:name] if args.key?(:name)
  @ssml_gender = args[:ssml_gender] if args.key?(:ssml_gender)
  @voice_clone = args[:voice_clone] if args.key?(:voice_clone)
end